"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const zosmf_for_zowe_sdk_1 = require("@zowe/zosmf-for-zowe-sdk");
const imperative_1 = require("@zowe/imperative");
const core_for_zowe_sdk_1 = require("@zowe/core-for-zowe-sdk");
/**
 * This class is used by the auth command handlers as the base class for their implementation.
 */
class ApimlAutoInitHandler extends imperative_1.BaseAutoInitHandler {
    constructor() {
        super(...arguments);
        /**
         * The profile type where token type and value should be stored
         */
        this.mProfileType = "base";
        /**
         * The description of your service to be used in CLI prompt messages
         */
        this.mServiceDescription = "your API Mediation Layer";
        /**
         * This is called by the {@link BaseAuthHandler#process} when it needs a
         * session. Should be used to create a session to connect to the auto-init
         * service.
         * @param {ICommandArguments} args The command line arguments to use for building the session
         * @returns {ISession} The session object built from the command line arguments.
         */
        this.createSessCfgFromArgs = zosmf_for_zowe_sdk_1.ZosmfSession.createSessCfgFromArgs;
    }
    /**
     * This is called by the "auto-init" command after it creates a session, to generate a configuration
     * @param {AbstractSession} session The session object to use to connect to the configuration service
     * @returns {Promise<string>} The response from the auth service containing a token
     * @throws {ImperativeError}
     */
    doAutoInit(session, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const restErrUnauthorized = 403;
            const configs = core_for_zowe_sdk_1.Services.getPluginApimlConfigs();
            let profileInfos;
            try {
                profileInfos = yield core_for_zowe_sdk_1.Services.getServicesByConfig(session, configs);
            }
            catch (err) {
                if (err instanceof imperative_1.RestClientError && err.mDetails && err.mDetails.httpStatus && err.mDetails.httpStatus === restErrUnauthorized) {
                    throw new imperative_1.ImperativeError({
                        msg: "HTTP(S) error status 403 received. Verify the user has access to the APIML API Services SAF resource.",
                        additionalDetails: err.mDetails.additionalDetails,
                        causeErrors: err
                    });
                }
                else {
                    throw err;
                }
            }
            const profileConfig = core_for_zowe_sdk_1.Services.convertApimlProfileInfoToProfileConfig(profileInfos);
            // Populate the config with base profile information
            if (profileConfig.defaults.base == null && profileConfig.profiles.base == null) {
                profileConfig.profiles.base = {
                    type: "base",
                    properties: {
                        host: session.ISession.hostname,
                        port: session.ISession.port
                    },
                    secure: []
                };
                profileConfig.defaults.base = "base";
                if (session.ISession.tokenType != null && session.ISession.tokenValue != null) {
                    profileConfig.profiles.base.properties.tokenType = session.ISession.tokenType;
                    profileConfig.profiles.base.properties.tokenValue = session.ISession.tokenValue;
                    profileConfig.profiles.base.secure.push("tokenValue");
                }
                else if (session.ISession.user && session.ISession.password) {
                    const tokenType = imperative_1.SessConstants.TOKEN_TYPE_APIML;
                    session.ISession.tokenType = tokenType;
                    session.ISession.type = imperative_1.SessConstants.AUTH_TYPE_TOKEN;
                    const tokenValue = yield core_for_zowe_sdk_1.Login.apimlLogin(session);
                    profileConfig.profiles.base.properties.tokenType = tokenType;
                    profileConfig.profiles.base.properties.tokenValue = tokenValue;
                    profileConfig.profiles.base.secure.push("tokenValue");
                }
            }
            return profileConfig;
        });
    }
}
exports.default = ApimlAutoInitHandler;
//# sourceMappingURL=ApimlAutoInitHandler.js.map